@@ -136,6 +136,7 @@ calibrate_CML_sol = function(scoretab, design, sufI, a, first, last, nIter, fixe
   bk_design = split(design, design$booklet_id,drop=TRUE)
   bk_scoretab = split(scoretab, scoretab$booklet_id,drop=TRUE)
   
+
   if (is.null(fixed_b)) # if no fixed parameters
   {
     nn= sum(sufI)
@@ -143,7 +144,7 @@ calibrate_CML_sol = function(scoretab, design, sufI, a, first, last, nIter, fixe
     ## Implicit Equations  ###
     converged=FALSE
     iter=0
-    pb = txtProgressBar(min=0, max=nIter)
+
     while ((!converged)&&(iter<=nIter))
     {
       iter=iter+1
@@ -158,7 +159,6 @@ calibrate_CML_sol = function(scoretab, design, sufI, a, first, last, nIter, fixe
       {
         return(calibrate_Bayes(scoretab, design, sufI, a, first, last,  nIter, fixed_b=fixed_b))
       }
-      setTxtProgressBar(pb, value=iter)
     }
     ie_iter=iter
     if (!converged) warning(paste('Implicit Equations not Converged in',as.character(nIter),"iterations"))
@@ -210,11 +210,9 @@ calibrate_CML_sol = function(scoretab, design, sufI, a, first, last, nIter, fixe
         return(calibrate_Bayes(scoretab, design, sufI, a, first, last,  nIter, fixed_b=fixed_b))
       }
       
-      
-      setTxtProgressBar(pb, value=iter)
       if (nr_iter==2) scale=1
     }
-    close(pb)
+
     if (!converged) warning(paste('Newton-Raphson not Converged in',as.character(nr_iter),"iterations"))
   }else  ### if fixed parameters
   {
@@ -230,7 +228,7 @@ calibrate_CML_sol = function(scoretab, design, sufI, a, first, last, nIter, fixe
     
     converged=FALSE
     iter=0
-    pb = txtProgressBar(min=0, max=nIter)
+
     while ((!converged)&&(iter<=nIter))
     {
       iter=iter+1
@@ -245,7 +243,7 @@ calibrate_CML_sol = function(scoretab, design, sufI, a, first, last, nIter, fixe
       {
         return(calibrate_Bayes(scoretab, design, sufI, a, first, last,  nIter, fixed_b=fixed_b))
       }
-      setTxtProgressBar(pb, value=iter)
+
     }
     ie_iter=iter
     if (!converged) warning(paste('Implicit Equations not Converged in',as.character(nIter),"iterations"))
@@ -289,11 +287,9 @@ calibrate_CML_sol = function(scoretab, design, sufI, a, first, last, nIter, fixe
         return(calibrate_Bayes(scoretab, design, sufI, a, first, last,  nIter, fixed_b=fixed_b))
       }
       
-      
-      setTxtProgressBar(pb, value=iter)
       scale=1
     }
-    close(pb)
+
     if (!converged) warning(paste('Newton-Raphson not Converged in',as.character(nr_iter),"iterations"))
   }
   
